import java.io.*;
import java.security.*;
import java.security.spec.*;
import java.security.interfaces.*;

public class AuthenticatorKeyPair {

    private PublicKey           authenticatorPublicKey;
    private PrivateKey          authenticatorPrivateKey;
    private byte[]              authenticatorEncodedPublicKey;

    public AuthenticatorKeyPair() {
        try {
            // Authenticator's public/private keys generator
            // This will be replaced by reading keys from keys repository
            KeyPairGenerator authenticatorKeyGen = KeyPairGenerator.getInstance("DSA");
            authenticatorKeyGen.initialize(1024, new SecureRandom());
            KeyPair kPair = authenticatorKeyGen.generateKeyPair();
            authenticatorPublicKey = kPair.getPublic();
            authenticatorPrivateKey = kPair.getPrivate();
            authenticatorEncodedPublicKey = authenticatorPublicKey.getEncoded();
        } catch (Exception ex) {
            System.err.println("AuthenticatorKeyPair Exception-> " + ex);
        }
    }

    public byte[] getEncodedPublicKey() {
        return this.authenticatorEncodedPublicKey;
    }

    public PublicKey getPublicKey() {
        return this.authenticatorPublicKey;
    }

    public PrivateKey getPrivateKey() {
        return this.authenticatorPrivateKey;
    }
}
